"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SyntaxHighlighter = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
let highlighterInstance = null;
async function getHighlighter() {
  if (!highlighterInstance) {
    highlighterInstance = await (0, _core.createHighlighterCore)({
      engine: (0, _engineJavascript.createJavaScriptRegexEngine)()
    });
  }
  return highlighterInstance;
}
const SyntaxHighlighter = ({
  text,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [tokens, setTokens] = _react.default.useState([]);
  const [loading, setLoading] = _react.default.useState(true);
  const [error, setError] = _react.default.useState(null);

  // Normalize theme
  const normalizedTheme = (0, _react.useMemo)(() => {
    console.log('Raw theme:', theme);
    const normalized = (0, _core.normalizeTheme)(theme);
    console.log('Normalized theme:', normalized);
    return normalized;
  }, [theme]);

  // Inside highlight function:
  _react.default.useEffect(() => {
    const highlight = async () => {
      try {
        setLoading(true);
        const highlighter = await getHighlighter();

        // Log theme info before loading
        console.log('Theme before loading:', {
          name: normalizedTheme.name,
          settings: normalizedTheme.settings?.length,
          tokenColors: normalizedTheme.tokenColors?.length
        });

        // Load language and theme
        if (typeof language !== 'string') {
          await highlighter.loadLanguage(language);
        }
        await highlighter.loadTheme(normalizedTheme);

        // Log loaded languages and themes
        console.log('Loaded languages:', highlighter.getLoadedLanguages());
        console.log('Loaded themes:', highlighter.getLoadedThemes());

        // Get theme by name to verify it's loaded
        const loadedTheme = highlighter.getTheme(normalizedTheme.name);
        console.log('Loaded theme details:', {
          name: loadedTheme.name,
          settings: loadedTheme.settings?.length
        });

        // Highlight with debug info
        const result = highlighter.codeToTokens(text, {
          lang: typeof language === 'string' ? language : language.name,
          theme: normalizedTheme.name,
          includeExplanation: true
        });

        // Log detailed token info
        console.log('First line tokens:', result.tokens[0]?.map(token => ({
          content: token.content,
          color: token.color,
          fontStyle: token.fontStyle,
          scopes: token.explanation?.[0]?.scopes.map(s => ({
            scopeName: s.scopeName,
            themeMatches: s.themeMatches?.length
          }))
        })));
        setTokens(result.tokens);
        setError(null);
      } catch (err) {
        console.error('Highlighting error:', err);
        setError(err instanceof Error ? err.message : 'Failed to highlight code');
      } finally {
        setLoading(false);
      }
    };
    highlight();
  }, [text, language, normalizedTheme]);
  const renderToken = (token, index) => {
    const styles = [{
      fontSize
    }];
    if (textStyle) {
      styles.push(textStyle);
    }

    // Add color from token
    if (token.color) {
      styles.push({
        color: token.color
      });
    }

    // Add font styles
    if (token.fontStyle === 1) styles.push({
      fontStyle: 'italic'
    });
    if (token.fontStyle === 2) styles.push({
      fontWeight: 'bold'
    });
    if (token.fontStyle === 4) styles.push({
      textDecorationLine: 'underline'
    });

    // If token has no color, use theme's foreground color
    if (!token.color && normalizedTheme.fg) {
      styles.push({
        color: normalizedTheme.fg
      });
    }
    const finalStyle = _reactNative.StyleSheet.flatten(styles);
    console.log('Token style:', {
      content: token.content,
      color: token.color || normalizedTheme.fg,
      styles: finalStyle
    });
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: finalStyle,
      children: token.content
    }, `${token.offset}-${index}`);
  };
  const renderLine = (lineTokens, index) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: lineTokens.map((token, tokenIndex) => renderToken(token, tokenIndex))
  }, index);
  if (loading) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [{
        backgroundColor: normalizedTheme.bg,
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [{
        backgroundColor: normalizedTheme.bg,
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: {
          color: '#ff6b6b'
        },
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    style: [{
      backgroundColor: normalizedTheme.bg
    }, scrollViewProps?.style],
    contentContainerStyle: [containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
};
exports.SyntaxHighlighter = SyntaxHighlighter;
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map